@@ -281,6 +281,7 @@ class PyQuery(list):
         """Extend with anoter PyQuery object"""
         assert isinstance(other, self.__class__)
         self._extend(other[:])
+        return self
 
     def items(self, selector=None):
         """Iter over elements. Return PyQuery objects:
@@ -965,7 +966,44 @@ class PyQuery(list):
             'Youhou'
 
         """
-        return self.attr('value', value) or None
+        def _get_value(tag):
+            # <textarea>
+            if tag.tag == 'textarea':
+                return self._copy(tag).text()
+            # <select>
+            if tag.tag == 'select':
+                selected_option = self._copy(tag)('option[selected]:last')
+                if selected_option:
+                    return selected_option.attr('value')
+                return None
+            # <input> and everything else.
+            return self._copy(tag).attr('value') or None
+
+        def _set_value(pq, value):
+            for tag in pq:
+                # <textarea>
+                if tag.tag == 'textarea':
+                    self._copy(tag).text(value)
+                    continue
+                # <select>
+                if tag.tag == 'select':
+                    def _make_option_selected(_, elem):
+                        pq = self._copy(elem)
+                        if pq.attr('value') == value:
+                            pq.attr('selected', 'selected')
+                        else:
+                            pq.removeAttr('selected')
+                    self._copy(tag)('option').each(_make_option_selected)
+                    continue
+                # <input> and everything else.
+                self._copy(tag).attr('value', value)
+
+        if value is no_default:
+            if len(self):
+                return _get_value(self[0])
+        else:
+            _set_value(self, value)
+            return self
 
     def html(self, value=no_default, **kwargs):
         """Get or set the html representation of sub nodes.
